@@ -20,6 +20,7 @@ import urllib.parse
 import logging
 from ipaddress import ip_address, ip_network
 from hmac import compare_digest
+from typing import Union
 
 import ldap0
 from ldap0.ldapurl import LDAPUrl, is_ldapurl
@@ -41,9 +42,7 @@ from ..ldapsession import (
     LDAPSession,
     START_TLS_REQUIRED,
     START_TLS_NO,
-    UsernameNotFound,
     InvalidSimpleBindDN,
-    UsernameNotUnique,
 )
 from ..utctime import ts2repr
 from ..log import LogHelper, logger, log_exception
@@ -326,11 +325,9 @@ class AppHandler(LogHelper):
         assert isinstance(res, str), TypeError('res must be str, was %r', res)
         return res
 
-    def ldap_url_anchor(self, data):
-        if isinstance(data, LDAPUrl):
-            ldap_url = data
-        else:
-            ldap_url = LDAPUrl(ldapUrl=data)
+    def ldap_url_anchor(self, ldap_url: Union[str, LDAPUrl]) -> str:
+        if isinstance(ldap_url, str):
+            ldap_url = LDAPUrl(ldapUrl=ldap_url)
         command_func = {True:'read', False:'search'}[ldap_url.scope == ldap0.SCOPE_BASE]
         if ldap_url.hostport:
             command_text = 'Connect'
@@ -607,7 +604,7 @@ class AppHandler(LogHelper):
         if del_sid form parameter is present then delete the obsolete session
         """
         try:
-            del_sid = self.form.field['delsid'].value[0]
+            del_sid = self.form.field['delsid'].val[0]
         except IndexError:
             return
         try:
@@ -645,7 +642,7 @@ class AppHandler(LogHelper):
             self._handle_delsid()
             if 'ldapurl' in self.form.input_field_names:
                 # One form parameter with LDAP URL
-                ldap_url_input = self.form.field['ldapurl'].value[0]
+                ldap_url_input = self.form.field['ldapurl'].val[0]
                 try:
                     input_ldapurl = ExtendedLDAPUrl(ldap_url_input)
                 except ValueError as err:
@@ -654,9 +651,9 @@ class AppHandler(LogHelper):
                     )
             else:
                 input_ldapurl = ExtendedLDAPUrl()
-                conntype = int(self.form.getInputValue('conntype', [0])[0])
+                conntype = int(self.form.get_input_value('conntype', [0])[0])
                 input_ldapurl.urlscheme = CONNTYPE2URLSCHEME[conntype]
-                input_ldapurl.hostport = self.form.getInputValue('host', [None])[0]
+                input_ldapurl.hostport = self.form.get_input_value('host', [None])[0]
                 input_ldapurl.start_tls = str(
                     START_TLS_REQUIRED * (conntype == 1)
                 )
@@ -664,16 +661,16 @@ class AppHandler(LogHelper):
         # Separate parameters for dn, who, cred and scope
         # have predecence over parameters specified in LDAP URL
 
-        dn = self.form.getInputValue('dn', [input_ldapurl.dn])[0]
+        dn = self.form.get_input_value('dn', [input_ldapurl.dn])[0]
 
-        who = self.form.getInputValue('who', [None])[0]
+        who = self.form.get_input_value('who', [None])[0]
         if who is None:
             if input_ldapurl.who is not None:
                 who = input_ldapurl.who
         else:
             input_ldapurl.who = who
 
-        cred = self.form.getInputValue('cred', [None])[0]
+        cred = self.form.get_input_value('cred', [None])[0]
         if cred is None:
             if input_ldapurl.cred is not None:
                 cred = input_ldapurl.cred
@@ -700,7 +697,7 @@ class AppHandler(LogHelper):
         if not ldap0.dn.is_dn(dn, flags=1):
             raise ErrorExit('Invalid DN.')
 
-        scope_str = self.form.getInputValue(
+        scope_str = self.form.get_input_value(
             'scope',
             [
                 {False:str(input_ldapurl.scope), True:''}[input_ldapurl.scope is None]
@@ -794,8 +791,7 @@ class AppHandler(LogHelper):
         try:
 
             if self.command in FORM_CLASS and not is_ldapurl(self.form.query_string):
-                # get the input fields
-                self.form.getInputFields()
+                self.form.get_input_fields()
 
             # Check access here
             if not self.check_access(self.command):
@@ -921,7 +917,7 @@ class AppHandler(LogHelper):
             self._session_store.save(self.sid, self.ls)
             self.dn = self.dn
 
-            login_mech = self.form.getInputValue(
+            login_mech = self.form.get_input_value(
                 'login_mech',
                 [self.ldap_url.sasl_mech or '']
             )[0].upper() or None
@@ -951,7 +947,7 @@ class AppHandler(LogHelper):
                 ):
                 self.dn = self.dn
                 # real bind operation
-                login_search_root = self.form.getInputValue(
+                login_search_root = self.form.get_input_value(
                     'login_search_root',
                     [self.naming_context],
                 )[0]
@@ -961,13 +957,13 @@ class AppHandler(LogHelper):
                         cred or '',
                         login_mech,
                         ''.join((
-                            self.form.getInputValue('login_authzid_prefix', [''])[0],
-                            self.form.getInputValue(
+                            self.form.get_input_value('login_authzid_prefix', [''])[0],
+                            self.form.get_input_value(
                                 'login_authzid',
                                 [self.ldap_url.sasl_authzid or ''],
                             )[0],
                         )) or None,
-                        self.form.getInputValue('login_realm', [self.ldap_url.sasl_realm])[0],
+                        self.form.get_input_value('login_realm', [self.ldap_url.sasl_realm])[0],
                         self.binddn_mapping,
                         loginSearchRoot=login_search_root,
                     )
