@@ -116,9 +116,9 @@ INPUT_FORM_BEGIN_TMPL = """
 def get_entry_input(app):
 
     # Get all the attribute types
-    in_attrtype_list = app.form.getInputValue('in_at', [])
+    in_attrtype_list = app.form.get_input_value('in_at', [])
     # Get all the attribute values
-    in_value_list = app.form.getInputValue('in_av', [])
+    in_value_list = app.form.get_input_value('in_av', [])
 
     if len(in_attrtype_list) != len(in_value_list):
         logger.warning(
@@ -135,7 +135,7 @@ def get_entry_input(app):
     for i, attr_type in enumerate(in_attrtype_list):
         attr_value = in_value_list[i]
         if isinstance(attr_value, str):
-            attr_value = app.ls.uc_encode(attr_value)[0]
+            attr_value = attr_value.encode(app.ls.charset)
         try:
             entry[attr_type].append(attr_value)
         except KeyError:
@@ -182,9 +182,9 @@ def get_entry_input(app):
     # extend entry with LDIF input
     try:
         in_ldif = app.form.field['in_ldif'].ldif_records
-    except ValueError as e:
+    except ValueError as err:
         raise ErrorExit(
-            'LDIF parsing error: %s' % (app.form.s2d(str(e)))
+            'LDIF parsing error: %s' % (app.form.s2d(str(err)))
         )
     else:
         if in_ldif:
@@ -450,7 +450,7 @@ def object_class_form(
             misc_select_field_th = ''
             misc_select_field_td = ''
 
-        input_currentformtype = app.form.getInputValue('in_oft', ['Template'])[0]
+        input_currentformtype = app.form.get_input_value('in_oft', ['Template'])[0]
 
         add_structural_oc_html = structural_select_field.input_html(
             id_value='add_structural_oc',
@@ -620,7 +620,7 @@ def object_class_form(
         # end of ldif_template_select_html()
 
 
-    in_ocf = app.form.getInputValue('in_ocf', ['tmpl'])[0]
+    in_ocf = app.form.get_input_value('in_ocf', ['tmpl'])[0]
 
     command_hidden_fields = [('dn', app.dn)]
 
@@ -872,14 +872,14 @@ def w2l_addform(app, add_rdn, add_basedn, entry, msg='', invalid_attrs=None):
     if msg:
         msg = '<p class="ErrorMessage">%s</p>' % (msg)
 
-    input_formtype = app.form.getInputValue(
+    input_formtype = app.form.get_input_value(
         'in_ft',
-        app.form.getInputValue('in_oft', ['OC'])
+        app.form.get_input_value('in_oft', ['OC'])
     )[0]
 
     if 'in_oc' in app.form.input_field_names:
         # Read objectclass(es) from input form
-        entry['objectClass'] = [oc.encode('ascii') for oc in app.form.field['in_oc'].value]
+        entry['objectClass'] = [oc.encode('ascii') for oc in app.form.field['in_oc'].val]
 
     if input_formtype == 'OC' or not entry:
         # Output the web page with object class input form
@@ -999,20 +999,20 @@ def w2l_modifyform(app, entry, msg='', invalid_attrs=None):
     if msg:
         msg = '<p class="ErrorMessage">%s</p>' % (msg)
 
-    input_formtype = app.form.getInputValue(
+    input_formtype = app.form.get_input_value(
         'in_ft',
-        app.form.getInputValue('in_oft', ['Template'])
+        app.form.get_input_value('in_oft', ['Template'])
     )[0]
 
     if 'in_oc' in app.form.input_field_names:
         # Read objectclass(es) from input form
-        entry['objectClass'] = [oc.encode('ascii') for oc in app.form.field['in_oc'].value]
+        entry['objectClass'] = [oc.encode('ascii') for oc in app.form.field['in_oc'].val]
 
     old_entry, readonly_old_attr_oids = read_old_entry(app, app.dn, app.schema, None)
     if not entry:
         entry = old_entry
 
-    in_roattroids = app.form.getInputValue('in_roattroids', [])
+    in_roattroids = app.form.get_input_value('in_roattroids', [])
     if in_roattroids == ['nonePseudoValue;x-web2ldap-None']:
         readonly_attr_oids = None
     elif in_roattroids:
@@ -1100,7 +1100,7 @@ def w2l_modifyform(app, entry, msg='', invalid_attrs=None):
             app.form.hidden_field_html('in_assertion', gen_assertion_filter(app, entry), ''),
             '\n'.join([
                 app.form.hidden_field_html('in_oldattrtypes', at_name, '')
-                for at_name in app.form.getInputValue('in_oldattrtypes', entry.keys())
+                for at_name in app.form.get_input_value('in_oldattrtypes', entry.keys())
             ]),
         ))
     )
