@@ -302,7 +302,7 @@ def bulkmod_input_form(
         BULKMOD_FORM_TMPL.format(
             text_msg=error_msg,
             form_begin=app.begin_form('bulkmod', 'POST'),
-            field_bulkmod_ctrl=app.form.field['bulkmod_ctrl'].input_html(default=app.form.field['bulkmod_ctrl'].value),
+            field_bulkmod_ctrl=app.form.field['bulkmod_ctrl'].input_html(default=app.form.field['bulkmod_ctrl'].val),
             input_fields=input_fields,
             field_hidden_dn=app.form.hidden_field_html('dn', app.dn, app.dn),
             field_hidden_filterstr=app.form.hidden_field_html('filterstr', bulkmod_filter, bulkmod_filter),
@@ -363,7 +363,7 @@ def bulkmod_confirmation_form(
                     app.form.s2d(OID_REG.get(ctrl_oid, (ctrl_oid,))[0]),
                     app.form.s2d(ctrl_oid),
                 )
-                for ctrl_oid in app.form.field['bulkmod_ctrl'].value or []
+                for ctrl_oid in app.form.field['bulkmod_ctrl'].val or []
             ]) or '- none -',
             field_hidden_dn=app.form.hidden_field_html('dn', dn, dn),
             field_hidden_filterstr=app.form.hidden_field_html('filterstr', bulkmod_filter, bulkmod_filter),
@@ -391,25 +391,25 @@ def w2l_bulkmod(app):
     Applies bulk modifications to multiple LDAP entries
     """
 
-    bulkmod_submit = app.form.getInputValue('bulkmod_submit', [None])[0]
+    bulkmod_submit = app.form.get_input_value('bulkmod_submit', [None])[0]
 
-    bulkmod_at = app.form.getInputValue('bulkmod_at', [])
-    bulkmod_op = app.form.getInputValue('bulkmod_op', [])
-    bulkmod_av = app.form.getInputValue('bulkmod_av', [])
+    bulkmod_at = app.form.get_input_value('bulkmod_at', [])
+    bulkmod_op = app.form.get_input_value('bulkmod_op', [])
+    bulkmod_av = app.form.get_input_value('bulkmod_av', [])
 
-    bulkmod_cp = app.form.getInputValue('bulkmod_cp', [''])[0] == 'yes'
+    bulkmod_cp = app.form.get_input_value('bulkmod_cp', [''])[0] == 'yes'
 
-    scope = int(app.form.getInputValue('scope', [str(app.ldap_url.scope or ldap0.SCOPE_BASE)])[0])
+    scope = int(app.form.get_input_value('scope', [str(app.ldap_url.scope or ldap0.SCOPE_BASE)])[0])
 
-    bulkmod_filter = app.form.getInputValue(
+    bulkmod_filter = app.form.get_input_value(
         'filterstr',
         [(app.ldap_url.filterstr or '')]
     )[0] or '(objectClass=*)'
-    bulkmod_newsuperior = app.form.getInputValue('bulkmod_newsuperior', [''])[0]
+    bulkmod_newsuperior = app.form.get_input_value('bulkmod_newsuperior', [''])[0]
 
     # Generate a list of requested LDAPv3 extended controls to be sent along
     # with the modify requests
-    bulkmod_ctrl_oids = app.form.getInputValue('bulkmod_ctrl', [])
+    bulkmod_ctrl_oids = app.form.get_input_value('bulkmod_ctrl', [])
 
     if not len(bulkmod_at) == len(bulkmod_op) == len(bulkmod_av):
         raise ErrorExit('Invalid bulk modification input.')
@@ -454,7 +454,7 @@ def w2l_bulkmod(app):
     elif bulkmod_submit == 'Apply':
 
         # now gather list of extended controls to be used with search request
-        bulkmod_ctrl_oids = app.form.getInputValue('bulkmod_ctrl', [])
+        bulkmod_ctrl_oids = app.form.get_input_value('bulkmod_ctrl', [])
         conn_server_ctrls = {
             server_ctrl.controlType
             for server_ctrl in app.ls.l.req_ctrls['**all**']+app.ls.l.req_ctrls['**write**']+app.ls.l.req_ctrls['modify']
@@ -495,12 +495,12 @@ def w2l_bulkmod(app):
                 if bulk_mod_list:
                     try:
                         app.ls.l.modify_s(rdat.dn_s, bulk_mod_list, req_ctrls=bulkmod_server_ctrls)
-                    except ldap0.LDAPError as e:
+                    except ldap0.LDAPError as err:
                         modify_error_count += 1
                         ldap_error_html.append(
                             '<dt>%s</dt><dd>%s</dd>' % (
                                 app.form.s2d(rdat.dn_s),
-                                app.ldap_error_msg(e),
+                                app.ldap_error_msg(err),
                             )
                         )
                     else:
@@ -528,12 +528,12 @@ def w2l_bulkmod(app):
                                 new_superior=bulkmod_newsuperior,
                                 delold=app.cfg_param('bulkmod_delold', 0),
                             )
-                    except ldap0.LDAPError as e:
+                    except ldap0.LDAPError as err:
                         modrdn_error_count += 1
                         ldap_error_html.append(
                             '<dt>%s</dt><dd>%s</dd>' % (
                                 app.form.s2d(rdat.dn_s),
-                                app.form.s2d(str(e)),
+                                app.form.s2d(str(err)),
                             )
                         )
                     else:
