@@ -1,11 +1,11 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 web2ldap.app.entry - schema-aware Entry classes
 
 web2ldap - a web-based LDAP Client,
 see https://www.web2ldap.de for details
 
-(c) 1998-2021 by Michael Stroeder <michael@stroeder.com>
+(C) 1998-2022 by Michael Stroeder <michael@stroeder.com>
 
 This software is distributed under the terms of the
 Apache License Version 2.0 (Apache-2.0)
@@ -212,14 +212,14 @@ class InputFormEntry(DisplayEntry):
 
     def __init__(
             self, app, dn, schema, entry,
-            writeable_attr_oids,
+            readonly_attr_oids,
             existing_object_classes=None,
             invalid_attrs=None
         ):
         assert isinstance(dn, str), TypeError("Argument 'dn' must be str, was {!r}".format(dn))
         DisplayEntry.__init__(self, app, dn, schema, entry, 'field_sep', False)
         self.existing_object_classes = existing_object_classes
-        self.writeable_attr_oids = writeable_attr_oids
+        self.readonly_attr_oids = readonly_attr_oids
         self.invalid_attrs = invalid_attrs or {}
         new_object_classes = set(self.entry.object_class_oid_set()) - {
             self.entry._s.get_oid(ObjectClass, oc_name)
@@ -287,8 +287,8 @@ class InputFormEntry(DisplayEntry):
                 ) or (
                     # Check whether the server indicated this attribute
                     # not to be writeable by bound identity
-                    not self.writeable_attr_oids is None and
-                    not oid in self.writeable_attr_oids and
+                    not self.readonly_attr_oids is None and
+                    oid in self.readonly_attr_oids and
                     not oid in self.new_attribute_types_oids
                 ) or (
                     # Check whether attribute type/value is used in the RDN => not writeable
@@ -311,7 +311,6 @@ class InputFormEntry(DisplayEntry):
                         self._app.form.s2d(attr_inst.form_value(), sp_entity='  '),
                         self._app.form.s2d(attr_inst.form_value(), sp_entity='&nbsp;&nbsp;')
                     ),
-                    attr_inst.value_button(self._app.command, self.row_counter, '+'),
                     '</span>'*highlight_invalid,
                 )))
                 self.row_counter += 1
@@ -361,7 +360,7 @@ class InputFormEntry(DisplayEntry):
 
             self.attr_counter += 1
 
-        return '<a class="hide" id="in_a_%s"></a>%s' % (
+        return '<span id="in_a_%s">%s</span>' % (
             self._app.form.s2d(nameoroid),
             '\n<br>\n'.join(result),
         )
@@ -428,7 +427,7 @@ class InputFormEntry(DisplayEntry):
         attr_types = list(attr_type_names.keys())
         attr_types.sort(key=str.lower)
         for attr_type in attr_types:
-            attr_type_name = schema_anchor(self._app, attr_type, AttributeType, link_text='&raquo')
+            attr_type_name = schema_anchor(self._app, attr_type, AttributeType, link_text='&raquo;')
             attr_value_field_html = self[attr_type]
             self._app.outf.write(
                 '<tr>\n<td class="InputAttrType">\n%s\n</td>\n<td>\n%s\n</td>\n</tr>\n' % (
