@@ -3,7 +3,6 @@
 web2ldap plugin classes for Active Directory (for some information see draft-armijo-ldap-syntax)
 """
 
-import os
 import time
 import uuid
 from typing import Dict
@@ -13,7 +12,6 @@ import iso3166
 from ldap0.dn import is_dn
 from ldap0.msad import sid2sddl, sddl2sid
 
-from ... import ETC_DIR
 from ...web.forms import Field, Textarea
 from ...utctime import strftimeiso8601
 from ..searchform import SEARCH_OPT_IS_EQUAL
@@ -32,7 +30,6 @@ from ..schema.syntaxes import (
     Integer,
     OctetString,
     OID,
-    PropertiesSelectList,
     SelectList,
     Uri,
     XmlValue,
@@ -552,7 +549,7 @@ class DNWithOctetString(DistinguishedName):
 
     def _validate(self, attr_value: bytes) -> bool:
         try:
-            octet_tag, count, octet_string, dn = self._app.ls.uc_decode(attr_value)[0].split(':')
+            octet_tag, count, octet_string, dn = attr_value.decode(self._app.ls.charset).split(':')
         except ValueError:
             return False
         try:
@@ -599,10 +596,10 @@ class MsAdGUID(OctetString):
             object_guid_uuid = uuid.UUID(attr_value.decode('ascii').replace(':', ''))
         except ValueError:
             return OctetString.sanitize(self, attr_value)
-        return object_guid_uuid.bytes
+        return object_guid_uuid.bytes_le
 
     def display(self, vidx, links) -> str:
-        object_guid_uuid = uuid.UUID(bytes=self._av)
+        object_guid_uuid = uuid.UUID(bytes_le=self._av)
         return '{%s}<br>%s' % (
             str(object_guid_uuid),
             OctetString.display(self, vidx, links),
@@ -920,6 +917,7 @@ syntax_registry.reg_at(
         '1.2.840.113556.1.4.583', # meetingURL
         '1.2.840.113556.1.2.464', # wWWHomePage
         '1.2.840.113556.1.4.749', # url
+        '1.2.840.113556.1.6.24.1.1', # msRTCSIP-PrimaryUserAddress
     ]
 )
 
