@@ -14,7 +14,6 @@ https://www.apache.org/licenses/LICENSE-2.0
 
 import binascii
 import sys
-import os
 import re
 import imghdr
 import sndhdr
@@ -33,7 +32,11 @@ from typing import (
     Pattern,
     Sequence,
     Tuple,
+    Union,
 )
+import ipaddress
+from collections import defaultdict
+from io import BytesIO
 
 import iso3166
 
@@ -51,9 +54,6 @@ except ImportError:
 else:
     PHONENUMBERS_AVAIL = True
 
-from collections import defaultdict
-from io import BytesIO
-
 # Detect Python Imaging Library (PIL)
 try:
     from PIL import Image as PILImage
@@ -63,8 +63,6 @@ else:
     PIL_AVAIL = True
     warnings.simplefilter('error', PILImage.DecompressionBombWarning)
 
-import ipaddress
-
 import ldap0
 import ldap0.ldapurl
 from ldap0.schema.models import AttributeType, ObjectClass, OBJECTCLASS_KIND_STR
@@ -75,7 +73,6 @@ from ldap0.schema.subentry import SubSchema
 
 import web2ldapcnf
 
-from ... import ETC_DIR
 from ...web import forms as web_forms
 from ...msbase import ascii_dump, chunks
 from ...utctime import repr2ts, ts2repr, strftimeiso8601
@@ -315,7 +312,7 @@ class LDAPSyntax:
     @property
     def av_u(self):
         if (self._av is not None and self._av_u is None):
-            self._av_u = self._app.ls.uc_decode(self._av)[0]
+            self._av_u = self._av.decode(self._app.ls.charset)
         return self._av_u
 
     def sanitize(self, attr_value: bytes) -> bytes:
@@ -524,7 +521,7 @@ class DirectoryString(LDAPSyntax):
 
     def _validate(self, attr_value: bytes) -> bool:
         try:
-            self._app.ls.uc_decode(attr_value)
+            attr_value.decode(self._app.ls.charset)
         except UnicodeDecodeError:
             return False
         return True
@@ -547,7 +544,7 @@ class DistinguishedName(DirectoryString):
     ref_attrs: Optional[Sequence[Tuple[Optional[str], str, Optional[str], str]]] = None
 
     def _validate(self, attr_value: bytes) -> bool:
-        return is_dn(self._app.ls.uc_decode(attr_value)[0])
+        return is_dn(attr_value.decode(self._app.ls.charset))
 
     def _additional_links(self):
         res = []
@@ -676,7 +673,7 @@ class NameAndOptionalUID(DistinguishedName):
         return dn, uid
 
     def _validate(self, attr_value: bytes) -> bool:
-        dn, _ = self._split_dn_and_uid(self._app.ls.uc_decode(attr_value)[0])
+        dn, _ = self._split_dn_and_uid(attr_value.decode(self._app.ls.charset))
         return is_dn(dn)
 
     def display(self, vidx, links) -> str:
@@ -787,7 +784,7 @@ class GeneralizedTime(IA5String):
         return result
 
     def sanitize(self, attr_value: bytes) -> bytes:
-        av_u = self._app.ls.uc_decode(attr_value.strip().upper())[0]
+        av_u = attr_value.strip().upper().decode(self._app.ls.charset)
         # Special cases first
         if av_u in {'N', 'NOW', '0'}:
             return datetime.datetime.strftime(
@@ -915,11 +912,11 @@ class NullTerminatedDirectoryString(DirectoryString):
         return attr_value.endswith(b'\x00')
 
     def form_value(self) -> str:
-        return self._app.ls.uc_decode((self._av or b'\x00')[:-1])[0]
+        return (self._av or b'\x00')[:-1].decode(self._app.ls.charset)
 
     def display(self, vidx, links) -> str:
         return self._app.form.s2d(
-            self._app.ls.uc_decode((self._av or b'\x00')[:-1])[0]
+            (self._av or b'\x00')[:-1].decode(self._app.ls.charset)
         )
 
 
@@ -949,7 +946,7 @@ class Integer(IA5String):
         if self.max_value is not None:
             self.max_len = len(str(self.max_value))
 
-    def _maxlen(self, fval):
+    def _maxlen(self, fval: str) -> int:
         min_value_len = max_value_len = fval_len = 0
         if self.min_value is not None:
             min_value_len = len(str(self.min_value))
@@ -1310,7 +1307,7 @@ class LDAPUrl(Uri):
     oid: str = 'LDAPUrl-oid'
     desc: str = 'LDAP URL'
 
-    def _command_ldap_url(self, ldap_url):
+    def _command_ldap_url(self, ldap_url: str) -> Union[str, ldap0.ldapurl.LDAPUrl]:
         return ldap_url
 
     def display(self, vidx, links) -> str:
@@ -1419,13 +1416,13 @@ class MultilineText(DirectoryString):
 
     def display(self, vidx, links) -> str:
         return '<br>'.join([
-            self._app.form.s2d(self._app.ls.uc_decode(line_b)[0])
+            self._app.form.s2d(line_b.decode(self._app.ls.charset))
             for line_b in self._split_lines(self._av)
         ])
 
     def form_value(self) -> str:
         splitted_lines = [
-            self._app.ls.uc_decode(line_b)[0]
+            line_b.decode(self._app.ls.charset)
             for line_b in self._split_lines(self._av or b'')
         ]
         return '\r\n'.join(splitted_lines)
@@ -1455,7 +1452,7 @@ class PreformattedMultilineText(MultilineText):
     def display(self, vidx, links) -> str:
         lines = [
             self._app.form.s2d(
-                self._app.ls.uc_decode(line_b)[0],
+                line_b.decode(self._app.ls.charset),
                 self.tab_identiation,
             )
             for line_b in self._split_lines(self._av)
@@ -1627,7 +1624,7 @@ class Date(IA5String):
     def _validate(self, attr_value: bytes) -> bool:
         try:
             datetime.datetime.strptime(
-                self._app.ls.uc_decode(attr_value)[0],
+                attr_value.decode(self._app.ls.charset),
                 self.storage_format
             )
         except (UnicodeDecodeError, ValueError):
@@ -1695,7 +1692,7 @@ class DateOfBirth(ISO8601Date):
     def _validate(self, attr_value: bytes) -> bool:
         try:
             birth_dt = datetime.datetime.strptime(
-                self._app.ls.uc_decode(attr_value)[0],
+                attr_value.decode(self._app.ls.charset),
                 self.storage_format
             )
         except ValueError:
@@ -1826,7 +1823,7 @@ class SelectList(DirectoryString):
         vdict = self.get_attr_value_dict()
         # Remove other existing values from the options dict
         for val in self._entry.get(self._at, []):
-            val = self._app.ls.uc_decode(val)[0]
+            val = val.decode(self._app.ls.charset)
             if val != fval:
                 try:
                     del vdict[val]
@@ -1849,7 +1846,7 @@ class SelectList(DirectoryString):
 
     def _validate(self, attr_value: bytes) -> bool:
         attr_value_dict: Dict[str, str] = self.get_attr_value_dict()
-        return self._app.ls.uc_decode(attr_value)[0] in attr_value_dict
+        return attr_value.decode(self._app.ls.charset) in attr_value_dict
 
     def display(self, vidx, links) -> str:
         attr_value_str = DirectoryString.display(self, vidx, links)
@@ -1976,7 +1973,7 @@ class DynamicValueSelectList(SelectList, DirectoryString):
         return None
 
     def _validate(self, attr_value: bytes) -> bool:
-        av_u = self._app.ls.uc_decode(attr_value)[0]
+        av_u = attr_value.decode(self._app.ls.charset)
         if (
                 not av_u.startswith(self.value_prefix) or
                 not av_u.endswith(self.value_suffix) or
@@ -2702,7 +2699,7 @@ class SchemaDescription(DirectoryString):
         if self.schema_cls is None:
             return DirectoryString._validate(self, attr_value)
         try:
-            _ = self.schema_cls(self._app.ls.uc_decode(attr_value)[0])
+            _ = self.schema_cls(attr_value.decode(self._app.ls.charset))
         except (IndexError, ValueError):
             return False
         return True
