@@ -1,10 +1,11 @@
+# -*- coding: ascii -*-
 """
 web2ldap.ldaputil.asynch - handle async LDAP operations
 
 web2ldap - a web-based LDAP Client,
 see https://www.web2ldap.de for details
 
-(c) 1998-2021 by Michael Stroeder <michael@stroeder.com>
+(C) 1998-2022 by Michael Stroeder <michael@stroeder.com>
 
 This software is distributed under the terms of the
 Apache License Version 2.0 (Apache-2.0)
@@ -119,7 +120,10 @@ class AsyncSearchHandler:
                 self.endResultBreak = result_counter
         finally:
             if partial and self._msg_id is not None:
-                self._l.abandon(self._msg_id)
+                try:
+                    self._l.abandon(self._msg_id)
+                except ldap0.NO_SUCH_OPERATION:
+                    pass
         self.post_processing()
         return partial # process_results()
 
