@@ -1,11 +1,11 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 ldaputil.passwd - client-side password setting
 
 web2ldap - a web-based LDAP Client,
 see https://www.web2ldap.de for details
 
-(c) 1998-2021 by Michael Stroeder <michael@stroeder.com>
+(C) 1998-2022 by Michael Stroeder <michael@stroeder.com>
 
 This software is distributed under the terms of the
 Apache License Version 2.0 (Apache-2.0)
@@ -20,42 +20,42 @@ import secrets
 from ldap0.pw import random_string, PWD_UNIX_CRYPT_ALPHABET
 
 AVAIL_USERPASSWORD_SCHEMES = {
-    u'crypt': u'Unix crypt(3)',
-    u'sha': u'SHA-1',
-    u'ssha': u'salted SHA-1',
-    u'md5': u'MD5',
-    u'smd5': u'salted MD5',
-    u'sha256': u'SHA-256',
-    u'ssha256': u'salted SHA-256',
-    u'sha384': u'SHA-384',
-    u'ssha384': u'salted SHA-384',
-    u'sha512': u'SHA-512',
-    u'ssha512': u'salted SHA-512',
-    u'': u'plain text',
+    'crypt': 'Unix crypt(3)',
+    'sha': 'SHA-1',
+    'ssha': 'salted SHA-1',
+    'md5': 'MD5',
+    'smd5': 'salted MD5',
+    'sha256': 'SHA-256',
+    'ssha256': 'salted SHA-256',
+    'sha384': 'SHA-384',
+    'ssha384': 'salted SHA-384',
+    'sha512': 'SHA-512',
+    'ssha512': 'salted SHA-512',
+    '': 'plain text',
 }
 
 
 SALTED_USERPASSWORD_SCHEMES = {
-    u'smd5',
-    u'ssha',
-    u'ssha256',
-    u'ssha384',
-    u'ssha512',
+    'smd5',
+    'ssha',
+    'ssha256',
+    'ssha384',
+    'ssha512',
 }
 
 
 # map lower-cased password scheme to hash function
 SCHEME2HASHLIBFUNC = {
-    u'sha': hashlib.sha1,
-    u'ssha': hashlib.sha1,
-    u'md5': hashlib.md5,
-    u'smd5': hashlib.md5,
-    u'sha256': hashlib.sha256,
-    u'ssha256': hashlib.sha256,
-    u'sha384': hashlib.sha384,
-    u'ssha384': hashlib.sha384,
-    u'sha512': hashlib.sha512,
-    u'ssha512': hashlib.sha512,
+    'sha': hashlib.sha1,
+    'ssha': hashlib.sha1,
+    'md5': hashlib.md5,
+    'smd5': hashlib.md5,
+    'sha256': hashlib.sha256,
+    'ssha256': hashlib.sha256,
+    'sha384': hashlib.sha384,
+    'ssha384': hashlib.sha384,
+    'sha512': hashlib.sha512,
+    'ssha512': hashlib.sha512,
 }
 
 
@@ -68,7 +68,7 @@ def user_password_hash(password, scheme, salt=None):
         return password
     if scheme not in AVAIL_USERPASSWORD_SCHEMES.keys():
         raise ValueError('Hashing scheme %r not supported.' % (scheme))
-    if scheme == u'crypt':
+    if scheme == 'crypt':
         encoded_pw = crypt.crypt(
             password.decode('utf-8'),
             random_string(PWD_UNIX_CRYPT_ALPHABET.decode('ascii'), 2)
