@@ -10,7 +10,6 @@ https://www.apache.org/licenses/LICENSE-2.0
 """
 
 import cgi
-import codecs
 import sys
 import re
 import urllib.parse
@@ -29,7 +28,7 @@ class Field:
     """
     __slots__ = (
         'accesskey',
-        '_charset',
+        'charset',
         'default',
         'maxLen',
         'maxValues',
@@ -37,7 +36,7 @@ class Field:
         '_re',
         'required',
         'text',
-        'value',
+        'val',
     )
 
     def __init__(
@@ -70,7 +69,7 @@ class Field:
             regex pattern of valid values either as string
             or tuple (pattern,options)
         """
-        self.value = []
+        self.val = []
         self.name = name
         self.text = text
         self.maxLen = maxLen
@@ -79,7 +78,7 @@ class Field:
         self.accesskey = accesskey
         # Charset is the preferred character set of the browser.
         # This is set by Form.add() to something meaningful.
-        self._charset = 'utf-8'
+        self.charset = 'utf-8'
         self.set_default(default)
         self.set_regex(pattern)
 
@@ -165,12 +164,13 @@ class Field:
                 raise InvalidValueFormat(self.name, self.text, value)
 
     def _validate_val_count(self):
-        if len(self.value) >= self.maxValues:
-            raise TooManyValues(self.name, self.text, len(self.value), self.maxValues)
+
+        if len(self.val) >= self.maxValues:
+            raise TooManyValues(self.name, self.text, len(self.val), self.maxValues)
 
     def _decode_val(self, value):
         """
-        Return str to be stored in self.value
+        Return str to be stored in self.val
         """
         try:
             value = value.decode(self.charset)
@@ -184,7 +184,7 @@ class Field:
         Store the user's value into the field object.
 
         This method can be used to modify the user's value
-        before storing it into self.value.
+        before storing it into self.val.
         """
         assert isinstance(value, (str, bytes)), TypeError(
             'Expected value to be str or bytes, was %r' % (value,)
@@ -196,17 +196,7 @@ class Field:
         # Format valid?
         self._validate_format(value)
         self._validate_val_count()
-        self.value.append(value)
-
-    @property
-    def charset(self):
-        """Return the character set used for the field"""
-        return self._charset
-
-    @charset.setter
-    def charset(self, charset):
-        """Set the character set used for the field"""
-        self._charset = charset
+        self.val.append(value)
 
     def _default_val(self, default):
         """returns default value"""
@@ -354,7 +344,7 @@ class File(Input):
 
     def _decode_val(self, value):
         """
-        Return bytes to be stored in self.value
+        Return bytes to be stored in self.val
         """
         return value
 
@@ -855,6 +845,7 @@ class Form:
     Class for declaring and processing a whole <form>
     """
     __slots__ = (
+        'accept_charset',
         'accept_language',
         'env',
         'field',
@@ -866,8 +857,6 @@ class Form:
         'query_string',
         'request_method',
         'script_name',
-        'uc_decode',
-        'uc_encode',
     )
 
     def __init__(self, inf, env):
@@ -889,30 +878,17 @@ class Form:
         self.script_name = env['SCRIPT_NAME']
         # Initialize the AcceptHeaderDict objects
         self.http_accept_charset = AcceptCharsetDict('HTTP_ACCEPT_CHARSET', env)
+        self.accept_charset = self.http_accept_charset.preferred()
         self.http_accept_language = AcceptHeaderDict('HTTP_ACCEPT_LANGUAGE', env)
         self.accept_language = self.http_accept_language.keys()
         self.http_accept_encoding = AcceptHeaderDict('HTTP_ACCEPT_ENCODING', env)
         # Determine query string
         self.query_string = env.get('QUERY_STRING', '')
-        # initialize Unicode codecs
-        self._set_charset()
         # add Field instances
         for field in self.fields():
             self.add_field(field)
         # end of Form.__init__()
 
-    @property
-    def accept_charset(self):
-        return self.http_accept_charset.preferred()
-
-    def getContentType(self):
-        """
-        Determine the HTTP content type of HTTP request
-        """
-        if self.request_method == 'POST':
-            return self.env.get('CONTENT_TYPE', 'application/x-www-form-urlencoded').lower() or None
-        return 'application/x-www-form-urlencoded'
-
     def fields(self):
         """
         Return a list of Field instances to be added to this Form instance.
@@ -927,18 +903,18 @@ class Form:
         self.field[field.name] = field
         # end of Form.add_field()
 
-    def getInputValue(self, name, default=None):
+    def get_input_value(self, name, default=None):
         """
         Return input value of a field defined by name if presented
         in form input. Return default else.
         """
         if name in self.input_field_names:
-            return self.field[name].value
+            return self.field[name].val
         if name in self.field:
             return default
         raise KeyError('Invalid field name %r requested for %s' % (name, self.__class__.__name__))
 
-    def allInputFields(self, fields=None, ignore_fields=None):
+    def list_fields(self, fields=None, ignore_fields=None):
         """
         Return list with all former input parameters.
 
@@ -951,9 +927,9 @@ class Form:
                 self.field[p]
                 for p in self.input_field_names-ignore_fields
             ]:
-            for val in f.value:
+            for val in f.val:
                 result.append((f.name, val))
-        return result # allInputFields()
+        return result
 
     def hidden_fields(self, outf=sys.stdout, ignore_fields=None):
         """
@@ -969,7 +945,7 @@ class Form:
                 self.field[p]
                 for p in self.input_field_names-ignore_fields
             ]:
-            for val in field.value:
+            for val in field.val:
                 outf.write(
                     '<input type="hidden" name="%s" value="%s">\n\r' % (
                         field.name,
@@ -983,25 +959,24 @@ class Form:
         can be overwritten to add Field instances to the form
         """
 
-    def _set_charset(self):
-        form_codec = codecs.lookup(self.accept_charset)
-        self.uc_encode, self.uc_decode = form_codec[0], form_codec[1]
-        # end of _set_charset()
-
-    def _parse_url_encoded(self, max_content_length):
+    @property
+    def max_content_length(self) -> int:
+        """
+        calculate maximum acceptable content length
+        """
+        res = 0
+        for field in self.field.values():
+            res += field.maxValues * field.maxLen
+        return res
 
+    def _parse_url_encoded(self):
         if self.request_method == 'POST':
-            query_string = self.uc_decode(
-                self.inf.read(int(self.env['CONTENT_LENGTH']))
-            )[0]
+            query_string = self.inf.read(int(self.env['CONTENT_LENGTH'])).decode(self.accept_charset)
         elif self.request_method == 'GET':
             query_string = self.env.get('QUERY_STRING', '')
-
         if not query_string:
             return
-
         content_length = 0
-
         for name, value in urllib.parse.parse_qsl(
                 query_string,
                 keep_blank_values=True,
@@ -1010,53 +985,41 @@ class Form:
                 errors='strict',
                 max_num_fields=None
             ):
-
             if name not in self.field:
                 raise InvalidFieldName(name)
-
             content_length += len(value)
-
             # Overall length of input data still valid?
+            max_content_length = self.max_content_length
             if content_length > max_content_length:
                 raise ContentLengthExceeded(content_length, max_content_length)
-
             # Input is stored in field instance
             self.field[name].set_value(value)
             # Add name of field to set of input keys
             self.input_field_names.add(name)
-
         # end of _parse_url_encoded()
 
-    def _parse_mime_multipart(self, max_content_length):
-
+    def _parse_mime_multipart(self):
         _, pdict = cgi.parse_header(self.env['CONTENT_TYPE'])
         pdict['boundary'] = pdict['boundary'].encode('ascii')
         pdict['CONTENT-LENGTH'] = self.env['CONTENT_LENGTH'].encode('ascii')
         parts = cgi.parse_multipart(self.inf, pdict)
-
         content_length = 0
-
+        max_content_length = self.max_content_length
         for name in parts.keys():
-
             if name not in self.field:
                 raise InvalidFieldName(name)
-
             for value in parts[name]:
-
                 content_length += len(value)
                 # sum of all received input still valid?
                 if content_length > max_content_length:
                     raise ContentLengthExceeded(content_length, max_content_length)
-
                 # Input is stored in field instance
                 self.field[name].set_value(value)
                 # Add name of field to set of input keys
                 self.input_field_names.add(name)
-
         # end of _parse_mime_multipart()
 
-
-    def getInputFields(self):
+    def get_input_fields(self):
         """
         Process user's <form> input and store the values in each
         field instance's content attribute.
@@ -1064,23 +1027,11 @@ class Form:
         When a processing error occurs FormException (or derivatives)
         are raised.
         """
-
-        # Calculate maxContentLength
-        maxContentLength = 0
-        for _, field in self.field.items():
-            maxContentLength += field.maxValues * field.maxLen
-
-        content_type = self.getContentType()
-        if content_type.startswith('application/x-www-form-urlencoded'):
-            # Parse user's input
-            self._parse_url_encoded(maxContentLength)
-        elif content_type.startswith('multipart/form-data'):
-            self._parse_mime_multipart(
-                maxContentLength,
-            )
+        content_type = self.env.get('CONTENT_TYPE', '').lower()
+        if self.request_method == 'POST' and content_type.startswith('multipart/form-data'):
+            self._parse_mime_multipart()
         else:
-            raise FormException('Invalid content received: %r' % (content_type))
-
+            self._parse_url_encoded()
         # Are all required parameters present?
         missing_params = []
         for _, field in self.field.items():
@@ -1088,5 +1039,4 @@ class Form:
                 missing_params.append((field.name, field.text))
         if missing_params:
             raise ParamsMissing(missing_params)
-
-        # end of Form.getInputFields()
+        # end of Form.get_input_fields()
