@@ -43,9 +43,9 @@ EXTRACT_INVALID_ATTR_PATTERNS = (
     # OpenLDAP diagnostic messages
     re.compile(r"(?P<at>[a-zA-Z0-9;-]+): value #(?P<index>[0-9]+) invalid per syntax"),
     re.compile(r"object class '(?P<oc>[a-zA-Z0-9;-]+)' requires attribute '(?P<at>[a-zA-Z0-9;-]+)'"),
+    re.compile(r"'(?P<at>[a-zA-Z0-9;-]+)' can only appear in collectiveAttributeSubentry"),
 )
 
-
 #---------------------------------------------------------------------------
 # Constants
 #---------------------------------------------------------------------------
@@ -579,6 +579,7 @@ def extract_invalid_attr(app, ldap_err):
             else:
                 error_msg = app.ldap_error_msg(ldap_err)
             break
+    error_msg = info
     return error_msg, invalid_attrs
 
 
