@@ -45,13 +45,21 @@ class Session(WebSession, LogHelper):
     """
     session store
     """
+    __slots__ = (
+        'max_concurrent_sessions',
+        'remote_ip_sessions',
+        'session_ip_addr',
+        'max_session_count_per_ip',
+        'remote_ip_counter',
+        'expiry_thread',
+    )
 
     def __init__(
             self,
-            session_ttl,
+            session_ttl: int,
             session_check_vars,
-            max_sessions,
-            max_session_count_per_ip,
+            max_sessions: int,
+            max_session_count_per_ip: int,
         ):
         WebSession.__init__(self, session_ttl, session_check_vars, max_sessions)
         self.max_concurrent_sessions = 0
@@ -91,7 +99,7 @@ class Session(WebSession, LogHelper):
         self.log(logging.INFO, 'new(): created new session for remote_ip = %r', remote_ip)
         return session_id
 
-    def _remove_ip_assoc(self, sid, remote_ip):
+    def _remove_ip_assoc(self, sid: str, remote_ip: str):
         try:
             del self.session_ip_addr[sid]
         except KeyError:
@@ -105,7 +113,7 @@ class Session(WebSession, LogHelper):
                 del self.remote_ip_sessions[remote_ip]
         # end of _remove_ip_assoc()
 
-    def rename(self, old_sid, env):
+    def rename(self, old_sid: str, env):
         session_data = self.retrieve(old_sid, env)
         new_sid = self.new(env)
         self.save(new_sid, session_data)
@@ -117,8 +125,7 @@ class Session(WebSession, LogHelper):
         self._remove_ip_assoc(old_sid, remote_ip)
         return new_sid
 
-    def delete(self, sid):
-        assert isinstance(sid, str), TypeError('Expected sid to be str, got %r' % (sid))
+    def delete(self, sid: str):
         self.log(logging.DEBUG, 'delete(%r): remove session', sid)
         try:
             ls_local = self.sessiondict[sid][1]
@@ -159,7 +166,7 @@ class ExpiryThread(threading.Thread, LogHelper):
         '_stop_event',
     )
 
-    def __init__(self, session_obj, interval=60):
+    def __init__(self, session_obj, interval: float = 60):
         self._session_obj = session_obj
         self._interval = interval
         self._stop_event = threading.Event()
